@@ -46,6 +46,7 @@ from .type_defs import (
     DescribeDatastoreResponseTypeDef,
     DescribeLoggingOptionsResponseTypeDef,
     DescribePipelineResponseTypeDef,
+    EmptyResponseMetadataTypeDef,
     FileFormatConfigurationTypeDef,
     GetDatasetContentResponseTypeDef,
     LateDataRuleTypeDef,
@@ -112,7 +113,7 @@ class IoTAnalyticsClient(BaseClient):
         """
 
     def batch_put_message(
-        self, *, channelName: str, messages: Sequence["MessageTypeDef"]
+        self, *, channelName: str, messages: Sequence[MessageTypeDef]
     ) -> BatchPutMessageResponseTypeDef:
         """
         Sends messages to a channel.
@@ -143,9 +144,9 @@ class IoTAnalyticsClient(BaseClient):
         self,
         *,
         channelName: str,
-        channelStorage: "ChannelStorageTypeDef" = ...,
-        retentionPeriod: "RetentionPeriodTypeDef" = ...,
-        tags: Sequence["TagTypeDef"] = ...
+        channelStorage: ChannelStorageTypeDef = ...,
+        retentionPeriod: RetentionPeriodTypeDef = ...,
+        tags: Sequence[TagTypeDef] = ...
     ) -> CreateChannelResponseTypeDef:
         """
         Used to create a channel.
@@ -158,13 +159,13 @@ class IoTAnalyticsClient(BaseClient):
         self,
         *,
         datasetName: str,
-        actions: Sequence["DatasetActionTypeDef"],
-        triggers: Sequence["DatasetTriggerTypeDef"] = ...,
-        contentDeliveryRules: Sequence["DatasetContentDeliveryRuleTypeDef"] = ...,
-        retentionPeriod: "RetentionPeriodTypeDef" = ...,
-        versioningConfiguration: "VersioningConfigurationTypeDef" = ...,
-        tags: Sequence["TagTypeDef"] = ...,
-        lateDataRules: Sequence["LateDataRuleTypeDef"] = ...
+        actions: Sequence[DatasetActionTypeDef],
+        triggers: Sequence[DatasetTriggerTypeDef] = ...,
+        contentDeliveryRules: Sequence[DatasetContentDeliveryRuleTypeDef] = ...,
+        retentionPeriod: RetentionPeriodTypeDef = ...,
+        versioningConfiguration: VersioningConfigurationTypeDef = ...,
+        tags: Sequence[TagTypeDef] = ...,
+        lateDataRules: Sequence[LateDataRuleTypeDef] = ...
     ) -> CreateDatasetResponseTypeDef:
         """
         Used to create a dataset.
@@ -188,11 +189,11 @@ class IoTAnalyticsClient(BaseClient):
         self,
         *,
         datastoreName: str,
-        datastoreStorage: "DatastoreStorageTypeDef" = ...,
-        retentionPeriod: "RetentionPeriodTypeDef" = ...,
-        tags: Sequence["TagTypeDef"] = ...,
-        fileFormatConfiguration: "FileFormatConfigurationTypeDef" = ...,
-        datastorePartitions: "DatastorePartitionsTypeDef" = ...
+        datastoreStorage: DatastoreStorageTypeDef = ...,
+        retentionPeriod: RetentionPeriodTypeDef = ...,
+        tags: Sequence[TagTypeDef] = ...,
+        fileFormatConfiguration: FileFormatConfigurationTypeDef = ...,
+        datastorePartitions: DatastorePartitionsTypeDef = ...
     ) -> CreateDatastoreResponseTypeDef:
         """
         Creates a data store, which is a repository for messages.
@@ -205,8 +206,8 @@ class IoTAnalyticsClient(BaseClient):
         self,
         *,
         pipelineName: str,
-        pipelineActivities: Sequence["PipelineActivityTypeDef"],
-        tags: Sequence["TagTypeDef"] = ...
+        pipelineActivities: Sequence[PipelineActivityTypeDef],
+        tags: Sequence[TagTypeDef] = ...
     ) -> CreatePipelineResponseTypeDef:
         """
         Creates a pipeline.
@@ -215,7 +216,7 @@ class IoTAnalyticsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client/#create_pipeline)
         """
 
-    def delete_channel(self, *, channelName: str) -> None:
+    def delete_channel(self, *, channelName: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the specified channel.
 
@@ -223,7 +224,7 @@ class IoTAnalyticsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client/#delete_channel)
         """
 
-    def delete_dataset(self, *, datasetName: str) -> None:
+    def delete_dataset(self, *, datasetName: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the specified dataset.
 
@@ -231,7 +232,9 @@ class IoTAnalyticsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client/#delete_dataset)
         """
 
-    def delete_dataset_content(self, *, datasetName: str, versionId: str = ...) -> None:
+    def delete_dataset_content(
+        self, *, datasetName: str, versionId: str = ...
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the content of the specified dataset.
 
@@ -239,7 +242,7 @@ class IoTAnalyticsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client/#delete_dataset_content)
         """
 
-    def delete_datastore(self, *, datastoreName: str) -> None:
+    def delete_datastore(self, *, datastoreName: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the specified data store.
 
@@ -247,7 +250,7 @@ class IoTAnalyticsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client/#delete_datastore)
         """
 
-    def delete_pipeline(self, *, pipelineName: str) -> None:
+    def delete_pipeline(self, *, pipelineName: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the specified pipeline.
 
@@ -387,7 +390,9 @@ class IoTAnalyticsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client/#list_tags_for_resource)
         """
 
-    def put_logging_options(self, *, loggingOptions: "LoggingOptionsTypeDef") -> None:
+    def put_logging_options(
+        self, *, loggingOptions: LoggingOptionsTypeDef
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Sets or updates the IoT Analytics logging options.
 
@@ -398,7 +403,7 @@ class IoTAnalyticsClient(BaseClient):
     def run_pipeline_activity(
         self,
         *,
-        pipelineActivity: "PipelineActivityTypeDef",
+        pipelineActivity: PipelineActivityTypeDef,
         payloads: Sequence[Union[str, bytes, IO[Any], StreamingBody]]
     ) -> RunPipelineActivityResponseTypeDef:
         """
@@ -430,7 +435,7 @@ class IoTAnalyticsClient(BaseClient):
         pipelineName: str,
         startTime: Union[datetime, str] = ...,
         endTime: Union[datetime, str] = ...,
-        channelMessages: "ChannelMessagesTypeDef" = ...
+        channelMessages: ChannelMessagesTypeDef = ...
     ) -> StartPipelineReprocessingResponseTypeDef:
         """
         Starts the reprocessing of raw message data through the pipeline.
@@ -439,7 +444,7 @@ class IoTAnalyticsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client/#start_pipeline_reprocessing)
         """
 
-    def tag_resource(self, *, resourceArn: str, tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, resourceArn: str, tags: Sequence[TagTypeDef]) -> Dict[str, Any]:
         """
         Adds to or modifies the tags of the given resource.
 
@@ -459,9 +464,9 @@ class IoTAnalyticsClient(BaseClient):
         self,
         *,
         channelName: str,
-        channelStorage: "ChannelStorageTypeDef" = ...,
-        retentionPeriod: "RetentionPeriodTypeDef" = ...
-    ) -> None:
+        channelStorage: ChannelStorageTypeDef = ...,
+        retentionPeriod: RetentionPeriodTypeDef = ...
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Used to update the settings of a channel.
 
@@ -473,13 +478,13 @@ class IoTAnalyticsClient(BaseClient):
         self,
         *,
         datasetName: str,
-        actions: Sequence["DatasetActionTypeDef"],
-        triggers: Sequence["DatasetTriggerTypeDef"] = ...,
-        contentDeliveryRules: Sequence["DatasetContentDeliveryRuleTypeDef"] = ...,
-        retentionPeriod: "RetentionPeriodTypeDef" = ...,
-        versioningConfiguration: "VersioningConfigurationTypeDef" = ...,
-        lateDataRules: Sequence["LateDataRuleTypeDef"] = ...
-    ) -> None:
+        actions: Sequence[DatasetActionTypeDef],
+        triggers: Sequence[DatasetTriggerTypeDef] = ...,
+        contentDeliveryRules: Sequence[DatasetContentDeliveryRuleTypeDef] = ...,
+        retentionPeriod: RetentionPeriodTypeDef = ...,
+        versioningConfiguration: VersioningConfigurationTypeDef = ...,
+        lateDataRules: Sequence[LateDataRuleTypeDef] = ...
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Updates the settings of a dataset.
 
@@ -491,10 +496,10 @@ class IoTAnalyticsClient(BaseClient):
         self,
         *,
         datastoreName: str,
-        retentionPeriod: "RetentionPeriodTypeDef" = ...,
-        datastoreStorage: "DatastoreStorageTypeDef" = ...,
-        fileFormatConfiguration: "FileFormatConfigurationTypeDef" = ...
-    ) -> None:
+        retentionPeriod: RetentionPeriodTypeDef = ...,
+        datastoreStorage: DatastoreStorageTypeDef = ...,
+        fileFormatConfiguration: FileFormatConfigurationTypeDef = ...
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Used to update the settings of a data store.
 
@@ -503,8 +508,8 @@ class IoTAnalyticsClient(BaseClient):
         """
 
     def update_pipeline(
-        self, *, pipelineName: str, pipelineActivities: Sequence["PipelineActivityTypeDef"]
-    ) -> None:
+        self, *, pipelineName: str, pipelineActivities: Sequence[PipelineActivityTypeDef]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Updates the settings of a pipeline.
 
